.. _tutorials:

Tutorials
=========

Python
------

If you are not familiar with Python please read :ref:`python_info`.

.. toctree::
   :maxdepth: 3

   ../python

ASE
---

Most of the tutorials will use the :mod:`EMT <ase.calculators.emt>` potential,
but any other :mod:`Calculator <ase.calculators>` could be plugged in instead.

.. toctree::
   :maxdepth: 1

   surface
   manipulating_atoms
   atomization
   lattice_constant
   eos/eos
   constraints/diffusion
   selfdiffusion/al110
   neb/diffusion
   neb/idpp
   dissociation
   spacegroup/spacegroup
   md/md
   wannier/wannier
   minimahopping/minimahopping
   ga/ga_optimize
   ga/ga_fcc_alloys
 
   
NumPy
-----

If your ASE scripts make extensive use of matrices you may want to familiarize yourself with :ref:`numpy`.

.. toctree::
   :maxdepth: 3

   ../numpy


Further reading
---------------

For more details:

* Look at the documentation for the individual :mod:`modules <ase>`.
* See the automatically generated documentation ``Epydoc``: :epydoc:`ase`.
* Browse the `source code`_ online.
* Have a look at :mod:`~ase.calculators.siesta` exercises:

.. toctree::
   :maxdepth: 3

   ../exercises/exercises

.. _source code: http://trac.fysik.dtu.dk/projects/ase/browser/trunk


Videos
------

The following video tutorials are available:

 - **Overview and installation of ASE**, by Anthony Goodrow (duration: ~5min 30sec; size: 26 MB) - en: |oi_en|

.. |oi_en| image:: ../static/United_States_of_America.png
   :target: https://wiki.fysik.dtu.dk/ase-files/oi_en.avi

.. |oi_cn| image:: ../static/China.png
   :target: https://wiki.fysik.dtu.dk/ase-files/oi_ch.avi

